@@ -1,23 +1,29 @@
 package Sub::Quote;
 
-use strictures 1;
-
 sub _clean_eval { eval $_[0] }
 
-use Sub::Defer;
-use Scalar::Util qw(weaken);
-use base qw(Exporter);
+use Moo::_strictures;
 
-our $VERSION = '1.004_004';
+use Sub::Defer qw(defer_sub);
+use Scalar::Util qw(weaken);
+use Exporter qw(import);
+use B ();
+BEGIN {
+  *_HAVE_PERLSTRING = defined &B::perlstring ? sub(){1} : sub(){0};
+}
+
+our $VERSION = '1.999_001';
 $VERSION = eval $VERSION;
 
-our @EXPORT = qw(quote_sub unquote_sub quoted_from_sub);
+our @EXPORT = qw(quote_sub unquote_sub quoted_from_sub qsub);
 our @EXPORT_OK = qw(quotify capture_unroll inlinify);
 
 our %QUOTED;
 
 sub quotify {
-  defined $_[0] ? qq["\Q$_[0]\E"] : 'undef()';
+  ! defined $_[0]     ? 'undef()'
+  : _HAVE_PERLSTRING  ? B::perlstring($_[0])
+  : qq["\Q$_[0]\E"];
 }
 
 sub capture_unroll {
@@ -38,17 +44,15 @@ sub inlinify {
   if ($code =~ s/^(\s*package\s+([a-zA-Z0-9:]+);)//) {
     $do .= $1;
   }
-  if ($code =~ s{(\A\s*|\A# BEGIN quote_sub PRELUDE\n.*?# END quote_sub PRELUDE\n\s*)(^\s*)(my\s*\(([^)]+)\)\s*=\s*\@_;)$}{
-    my ($pre, $indent, $assign, $code_args) = ($1, $2, $3, $4);
-    if ($code_args eq $args) {
-      $pre . $indent . ($local ? 'local ' : '').'@_ = ('.$args.");\n"
-      . $indent . $assign;
+  if ($code =~ s{
+    \A((?:\#\ BEGIN\ quote_sub\ PRELUDE\n.*?\#\ END\ quote_sub\ PRELUDE\n)?\s*)
+    (^\s*) my \s* \(([^)]+)\) \s* = \s* \@_;
+  }{}xms) {
+    my ($pre, $indent, $code_args) = ($1, $2, $3);
+    $do .= $pre;
+    if ($code_args ne $args) {
+      $do .= $indent . 'my ('.$code_args.') = ('.$args.'); ';
     }
-    else {
-      $pre . 'my ('.$code_args.') = ('.$args.'); ';
-    }
-  }mse) {
-    #done
   }
   elsif ($local || $args ne '@_') {
     $do .= ($local ? 'local ' : '').'@_ = ('.$args.'); ';
@@ -160,6 +164,10 @@ sub unquote_sub {
   $$unquoted;
 }
 
+sub qsub ($) {
+  goto &quote_sub;
+}
+
 sub CLONE {
   %QUOTED = map { defined $_ ? (
     $_->[3] && ${$_->[3]} ? (${ $_->[3] } => $_) : (),
@@ -257,7 +265,7 @@ version for convenience.
  my $prelude = capture_unroll '$captures', {
    '$x' => 1,
    '$y' => 2,
- };
+ }, 4;
 
  my $inlined_code = inlinify q{
    my ($x, $y) = @_;
@@ -291,6 +299,18 @@ L</inlinify>.  C<$from> is a string will be used as a hashref in the resulting
 code.  The keys of C<%captures> are the names of the variables and the values
 are ignored.  C<$indent> is the number of spaces to indent the result by.
 
+=head2 qsub
+
+ my $hash = {
+  coderef => qsub q{ print "hello"; },
+  other   => 5,
+ };
+
+Arguments: $code
+
+Works exactly like L</quote_sub>, but includes a prototype to only accept a
+single parameter.  This makes it easier to include in hash structures or lists.
+
 =head1 CAVEATS
 
 Much of this is just string-based code-generation, and as a result, a few
